@@ -1,4 +1,6 @@
-from steinloss.loss_calculator import Loss_Calculator, PacketEntry, TimeTable
+from steinloss.loss_calculator import PacketEntry
+from steinloss.loss_calculator import Loss_Calculator
+from steinloss.loss_calculator import TimeTable
 
 
 class Data_Presenter(object):
